@@ -1,6 +1,7 @@
 use strict;
 use warnings;
-package MungeInstallers;
+package inc::MungeInstallers;
+# vim: set ts=8 sts=2 sw=2 tw=100 et :
 
 use utf8;
 use Moose;
@@ -9,17 +10,15 @@ use namespace::autoclean;
 
 # TODO - this should really be a separate phase that runs after InstallTool -
 # until then, all we can do is die if we are run too soon
-sub setup_installer
-{
+sub setup_installer {
     my $self = shift;
 
-    my @build_files = grep { $_->name eq 'Build.PL' } @{ $self->zilla->files };
+    my @build_files = grep $_->name eq 'Build.PL', @{ $self->zilla->files };
 
     $self->log_fatal('No Build.PL was found to munge!')
         if @build_files != 1;
 
-    for my $file (@build_files)
-    {
+    for my $file (@build_files) {
         # check for template markers in file content
         $self->log_fatal([ 'ran too soon, before %s template(s) evaluated', $file->name ])
             if $file->content =~ /\{\{/;
